==> rapidsvn_0.9.1.orig.tar.gz: rapidsvn-0.9.1/src/get_action.cpp <==
/*
 * ====================================================================
 * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt); if not, write to 
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */

// wxWidgets
#include "wx/wx.h"

// svncpp
#include "svncpp/client.hpp"
#include "svncpp/path.hpp"

// app
#include "ids.hpp"
#include "get_action.hpp"
#include "utils.hpp"

GetAction::GetAction (wxWindow * parent, const GetData & data)
  : Action (parent, _("Update"), GetBaseFlags ()),
    m_data (data)
{
}

bool
GetAction::Prepare ()
{
  return true;
}

bool
GetAction::Perform ()
{
  svn::Client client (GetContext ());

  wxSetWorkingDirectory (Utf8ToLocal (GetPath ().c_str ()));
  client.update (svn::Path (LocalToUtf8 (m_data.path)),
                 m_data.revision,
                 false);

  return true;
}
/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */

==> rapidsvn_0.9.4.orig.tar.gz: rapidsvn-0.9.4/src/get_action.cpp <==
/*
 * ====================================================================
 * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (in the file GPL.txt); if not, write to 
 * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 *
 * This software consists of voluntary contributions made by many
 * individuals.  For exact contribution history, see the revision
 * history and logs, available at http://rapidsvn.tigris.org/.
 * ====================================================================
 */

// wxWidgets
#include "wx/wx.h"

// svncpp
#include "svncpp/client.hpp"
#include "svncpp/path.hpp"

// app
#include "ids.hpp"
#include "get_action.hpp"
#include "utils.hpp"

GetAction::GetAction (wxWindow * parent, const GetData & data)
  : Action (parent, _("Update"), GetBaseFlags ()),
    m_data (data)
{
}

bool
GetAction::Prepare ()
{
  return true;
}

bool
GetAction::Perform ()
{
  svn::Client client (GetContext ());

  wxString msg;
  msg.Printf (wxT("Getting: %s, Revision %d"), m_data.path.c_str(), m_data.revision.revnum());
  Trace(msg);

  wxSetWorkingDirectory (Utf8ToLocal (GetPath ().c_str ()));
  client.update (svn::Path (LocalToUtf8 (m_data.path)),
                 m_data.revision,
                 true);

  return true;
}
/* -----------------------------------------------------------------
 * local variables:
 * eval: (load-file "../rapidsvn-dev.el")
 * end:
 */
